@@ -345,7 +345,7 @@ class R3sponse(object):
 		):
 			list = []
 			for key in keys:
-				list.append(key)
+				list.append(self[key])
 			return list
 		# clean default values.
 		def clean(self):
